import 'package:flutter/material.dart';
import 'package:dialog_manager/dialog_manager.dart';

class Test extends StatefulWidget {

  @override
  State<StatefulWidget> createState() {
    return TestState();
  }
}

class TestState extends State<Test> with DialogStateMixin {

  bool isShowingDialog;

  @override
  initState () {
    super.initState();
    isShowingDialog = false;
    Future(() {
      DialogManageProvider.of(context).addListener(this, context);
    });
  }

  @override
  dispose () {
    super.dispose();
    DialogManageProvider.of(context).removeListener(this, context);
  }

  @override
  onDialogShow () {
    print('Test当前页面的弹窗显示');
    setState(() {
      isShowingDialog = true;
    });
  }

  @override
  onDialogHide () {
    print('Test当前页面的弹窗隐藏');
    setState(() {
      isShowingDialog = false;
    });
  }

  Future<dynamic> showContent (String content, BuildContext context, { bool showNestBtn = false }) {
    return showDialog(
      context: context,
      builder: (BuildContext innerContext) {
        return Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[

            RaisedButton(
              onPressed: () {
                Navigator.of(innerContext).pop('弹窗关闭返回值');
              },
              child: Text('关闭弹窗', style: TextStyle(decoration: TextDecoration.none, fontSize: 20)),
            ),

            Container(
              width: 100,
              height: 100,
              alignment: Alignment.center,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
                color: Colors.red
              ),
              child: Text(
                content,
                style: TextStyle(
                  fontSize: 20,
                  decoration: TextDecoration.none,
                  color: Colors.black
                )
              ),
            ),

            showNestBtn ? RaisedButton(
              onPressed: () {
                showOneDialog(context);
              },
              child: Text('再次第二层弹窗'),
            ) : SizedBox.shrink()
          ],
        );
      }
    );
  }

  void showOneDialog (BuildContext context) {
    DialogManageProvider.of(context).requestShowDialog(context, () {
      return showContent('弹窗1', context);
    }).then((result) {
      print('showOneDialog result ${result}');
    });
  }

  void showNestDialog (BuildContext context) {
    DialogManageProvider.of(context).requestShowDialog(context, () {
      return showContent('弹窗1', context, showNestBtn: true);
    }).then((result) {
      print('showNestDialog result ${result}');
    });
  }

  void showConsequentDialog (BuildContext context) {
    DialogManageProvider.of(context).requestShowDialog(context, () {
      return showContent('弹窗2', context);
    }, priorityLevel: 10).then((result) {
      print('showConsequentDialog result2 ${result}');
    });

    DialogManageProvider.of(context).requestShowDialog(context, () {
      return showContent('弹窗1', context);
    }, priorityLevel: 0).then((result) {
      print('showConsequentDialog result1 ${result}');
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.green,
      alignment: Alignment.bottomCenter,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Text('当前页面是否有弹窗在显示： ${isShowingDialog}', style: TextStyle(fontSize: 25, color: Colors.white, decoration: TextDecoration.none),),
          RaisedButton(
            onPressed: () {
              showOneDialog(context);
            },
            child: Text('显示弹窗'),
          ),

          RaisedButton(
            onPressed: () {
              showConsequentDialog(context);
            },
            child: Text('连续显示两个弹窗', style: TextStyle(decoration: TextDecoration.none)),
          ),

          RaisedButton(
            onPressed: () {
              showNestDialog(context);
            },
            child: Text('嵌套显示弹窗', style: TextStyle(decoration: TextDecoration.none)),
          ),

          RaisedButton(
            onPressed: () {
              Navigator.of(context).pushNamed('home');
            },
            child: Text('返回Home页面', style: TextStyle(decoration: TextDecoration.none)),
          ),

          RaisedButton(
            onPressed: () {
              bool isShowing = DialogManageProvider.of(context).getIsShowingState(context);
              print('test页面的弹窗显示状态：${isShowing}');
            },
            child: Text('获取test页面的弹窗显示状态', style: TextStyle(decoration: TextDecoration.none)),
          )
        ],
      )
    );
  }
}